@@ -31,7 +31,7 @@ import aws_cdk.aws_lambda
 import aws_cdk.core
 import constructs
 
-from ._jsii import *
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-elasticloadbalancingv2-targets", "1.33.1", __name__, "aws-elasticloadbalancingv2-targets@1.33.1.jsii.tgz")
 
 
 @jsii.implements(aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancerTarget, aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancerTarget)
@@ -217,11 +217,6 @@ class LambdaTarget(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-elasticloadb
         return jsii.invoke(self, "attachToNetworkTargetGroup", [target_group])
 
 
-__all__ = [
-    "InstanceIdTarget",
-    "InstanceTarget",
-    "IpTarget",
-    "LambdaTarget",
-]
+__all__ = ["InstanceIdTarget", "InstanceTarget", "IpTarget", "LambdaTarget", "__jsii_assembly__"]
 
 publication.publish()
